<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SetRelativeZero</name>
    <message>
        <location filename="../SetRelativeZero.js" line="+50"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Proszę wskazać położenie</translation>
    </message>
    <message>
        <location filename="../SetRelativeZeroInit.js" line="+2"/>
        <source>Set &amp;Relative Zero</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ustal początek układu &amp;względnego</translation>
    </message>
</context>
</TS>
